public inbox for devicetree@vger.kernel.org
 help / color / mirror / Atom feed
From: Mark Brown <broonie@kernel.org>
Cc: "Mark Rutland" <mark.rutland@arm.com>,
	devicetree@vger.kernel.org, alsa-devel@alsa-project.org,
	"Tony Lindgren" <tony@atomide.com>,
	"Liam Girdwood" <lgirdwood@gmail.com>,
	"Rob Herring" <robh+dt@kernel.org>,
	linux-kernel@vger.kernel.org, "Mark Brown" <broonie@kernel.org>,
	"Benoît Cousson" <bcousson@baylibre.com>,
	"Andrew F . Davis" <afd@ti.com>
Subject: Applied "ASoC: tlv320aic31xx: File header and copyright cleanup" to the asoc tree
Date: Thu, 30 Nov 2017 12:33:01 +0000	[thread overview]
Message-ID: <E1eKO1V-0000Vn-EA@debutante> (raw)
In-Reply-To: <20171129213300.20021-2-afd@ti.com>

The patch

   ASoC: tlv320aic31xx: File header and copyright cleanup

has been applied to the asoc tree at

   https://git.kernel.org/pub/scm/linux/kernel/git/broonie/sound.git 

All being well this means that it will be integrated into the linux-next
tree (usually sometime in the next 24 hours) and sent to Linus during
the next merge window (or sooner if it is a bug fix), however if
problems are discovered then the patch may be dropped or reverted.  

You may get further e-mails resulting from automated or manual testing
and review of the tree, please engage with people reporting problems and
send followup patches addressing any issues that are reported if needed.

If any updates are required or you are submitting further changes they
should be sent as incremental updates against current git, existing
patches will not be replaced.

Please add any relevant lists and maintainers to the CCs when replying
to this mail.

Thanks,
Mark

>From b1c52b7e7cc6a57128869008b84d98a4de78fe2d Mon Sep 17 00:00:00 2001
From: "Andrew F. Davis" <afd@ti.com>
Date: Wed, 29 Nov 2017 15:32:42 -0600
Subject: [PATCH] ASoC: tlv320aic31xx: File header and copyright cleanup

Fix header copyright tags, while we are here, also switch to SPDX
and fixup MODULE tags to match.

Signed-off-by: Andrew F. Davis <afd@ti.com>
Signed-off-by: Mark Brown <broonie@kernel.org>
---
 sound/soc/codecs/tlv320aic31xx.c | 26 +++++++++-----------------
 sound/soc/codecs/tlv320aic31xx.h | 15 ++++-----------
 2 files changed, 13 insertions(+), 28 deletions(-)

diff --git a/sound/soc/codecs/tlv320aic31xx.h b/sound/soc/codecs/tlv320aic31xx.h
index 730fb2058869..a9ea2f99eba0 100644
--- a/sound/soc/codecs/tlv320aic31xx.h
+++ b/sound/soc/codecs/tlv320aic31xx.h
@@ -1,17 +1,10 @@
+// SPDX-License-Identifier: GPL-2.0
 /*
- * ALSA SoC TLV320AIC31XX codec driver
- *
- * Copyright (C) 2013 Texas Instruments, Inc.
- *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation.
- *
- * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * ALSA SoC TLV320AIC31xx CODEC Driver Definitions
  *
+ * Copyright (C) 2014-2017 Texas Instruments Incorporated - http://www.ti.com/
  */
+
 #ifndef _TLV320AIC31XX_H
 #define _TLV320AIC31XX_H
 
diff --git a/sound/soc/codecs/tlv320aic31xx.c b/sound/soc/codecs/tlv320aic31xx.c
index 4837f25b0760..b98d9b1f216f 100644
--- a/sound/soc/codecs/tlv320aic31xx.c
+++ b/sound/soc/codecs/tlv320aic31xx.c
@@ -1,22 +1,14 @@
+// SPDX-License-Identifier: GPL-2.0
 /*
  * ALSA SoC TLV320AIC31XX codec driver
  *
- * Copyright (C) 2014 Texas Instruments, Inc.
- *
- * Author: Jyri Sarha <jsarha@ti.com>
+ * Copyright (C) 2014-2017 Texas Instruments Incorporated - http://www.ti.com/
+ *	Jyri Sarha <jsarha@ti.com>
  *
  * Based on ground work by: Ajit Kulkarni <x0175765@ti.com>
  *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
- * published by the Free Software Foundation.
- *
- * THIS PACKAGE IS PROVIDED AS IS AND WITHOUT ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
- *
- * The TLV320AIC31xx series of audio codec is a low-power, highly integrated
- * high performance codec which provides a stereo DAC, a mono ADC,
+ * The TLV320AIC31xx series of audio codecs are low-power, highly integrated
+ * high performance codecs which provides a stereo DAC, a mono ADC,
  * and mono/stereo Class-D speaker driver.
  */
 
@@ -1414,6 +1406,6 @@ static struct i2c_driver aic31xx_i2c_driver = {
 
 module_i2c_driver(aic31xx_i2c_driver);
 
-MODULE_DESCRIPTION("ASoC TLV320AIC3111 codec driver");
-MODULE_AUTHOR("Jyri Sarha");
-MODULE_LICENSE("GPL");
+MODULE_AUTHOR("Jyri Sarha <jsarha@ti.com>");
+MODULE_DESCRIPTION("ASoC TLV320AIC31xx CODEC Driver");
+MODULE_LICENSE("GPL v2");
@@ -1,22 +1,14 @@
 /*
- * ALSA SoC TLV320AIC31XX codec driver
+ * ALSA SoC TLV320AIC31xx CODEC Driver
  *
-- 
2.15.0

  parent reply	other threads:[~2017-11-30 12:33 UTC|newest]

Thread overview: 63+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-11-29 21:32 [PATCH v2 00/19] Add Headphone Detection to TLV320AIC31xx Driver Andrew F. Davis
2017-11-29 21:32 ` [PATCH v2 01/19] ASoC: tlv320aic31xx: File header and copyright cleanup Andrew F. Davis
2017-11-30 12:29   ` Mark Brown
2017-11-30 12:33   ` Mark Brown [this message]
2017-11-29 21:32 ` [PATCH v2 02/19] ASoC: tlv320aic31xx: Change aic31xx_power_off return type to void Andrew F. Davis
2017-11-30 12:32   ` Applied "ASoC: tlv320aic31xx: Change aic31xx_power_off return type to void" to the asoc tree Mark Brown
     [not found] ` <20171129213300.20021-1-afd-l0cyMroinI0@public.gmane.org>
2017-11-29 21:32   ` [PATCH v2 03/19] ASoC: tlv320aic31xx: Move ACPI table next to OF table Andrew F. Davis
2017-11-30 12:32     ` Applied "ASoC: tlv320aic31xx: Move ACPI table next to OF table" to the asoc tree Mark Brown
2017-11-29 21:32   ` [PATCH v2 08/19] ASoC: tlv320aic31xx: Switch GPIO handling to use gpiod_* API Andrew F. Davis
2017-12-04 16:47     ` Andrew F. Davis
2017-12-05 21:23       ` Andrew F. Davis
2017-12-06 12:46         ` Mark Brown
2017-11-29 21:32   ` [PATCH v2 18/19] ASoC: tlv320aic31xx: Add headphone/headset detection Andrew F. Davis
     [not found]     ` <20171129213300.20021-19-afd-l0cyMroinI0@public.gmane.org>
2017-12-01 13:41       ` Mark Brown
2017-12-06 17:25         ` Andrew F. Davis
2017-12-06 17:32           ` Mark Brown
2017-12-06 17:47             ` Andrew F. Davis
2017-12-06 17:52               ` Mark Brown
2017-11-29 21:32 ` [PATCH v2 04/19] ASoC: tlv320aic31xx: General source formatting cleanup Andrew F. Davis
2017-12-01 13:43   ` Applied "ASoC: tlv320aic31xx: General source formatting cleanup" to the asoc tree Mark Brown
2017-11-29 21:32 ` [PATCH v2 05/19] ASoC: tlv320aic31xx: Fix GPIO1 register definition Andrew F. Davis
2017-11-30 12:32   ` Applied "ASoC: tlv320aic31xx: Fix GPIO1 register definition" to the asoc tree Mark Brown
2017-11-29 21:32 ` [PATCH v2 06/19] ASoC: tlv320aic31xx: Reformat header file using GENMASK and BIT macros Andrew F. Davis
2017-11-29 21:32 ` [PATCH v2 07/19] ASoC: tlv320aic31xx: Merge init function into probe Andrew F. Davis
2017-11-29 21:32 ` [PATCH v2 09/19] ASoC: tlv320aic31xx: Remove platform data Andrew F. Davis
     [not found]   ` <20171129213300.20021-10-afd-l0cyMroinI0@public.gmane.org>
2017-12-01 13:26     ` Mark Brown
2017-12-05 21:20       ` Andrew F. Davis
2017-12-06 12:45         ` Mark Brown
2017-12-06 16:19           ` Andrew F. Davis
     [not found]             ` <10f1b19b-4a0a-e336-b757-933d46b5c8e9-l0cyMroinI0@public.gmane.org>
2017-12-06 17:30               ` Mark Brown
2017-12-06 17:48                 ` Andrew F. Davis
     [not found]                   ` <b6f581be-6d3a-6fc3-036f-9efc1bfc2429-l0cyMroinI0@public.gmane.org>
2017-12-06 18:15                     ` Mark Brown
2017-12-06 18:40                       ` Andrew F. Davis
     [not found]                         ` <86e13e26-e8d5-35ed-6bd0-d91d9323d5e6-l0cyMroinI0@public.gmane.org>
2017-12-06 19:11                           ` Mark Brown
2017-12-06 19:15                             ` Andrew F. Davis
2017-11-29 21:32 ` [PATCH v2 10/19] ASoC: tlv320aic31xx: Add MICBIAS off setting Andrew F. Davis
     [not found]   ` <20171129213300.20021-11-afd-l0cyMroinI0@public.gmane.org>
2017-12-01 13:30     ` Mark Brown
2017-12-01 14:56       ` Andrew F. Davis
2017-12-01 17:43         ` Mark Brown
2017-11-29 21:32 ` [PATCH v2 11/19] ASoC: tlv320aic31xx: Check clock and divider before division Andrew F. Davis
2017-11-29 21:32 ` [PATCH v2 12/19] ASoC: tlv320aic31xx: Add CODEC clock slave support Andrew F. Davis
2017-12-01 13:43   ` Applied "ASoC: tlv320aic31xx: Add CODEC clock slave support" to the asoc tree Mark Brown
2017-11-29 21:32 ` [PATCH v2 13/19] ASoC: tlv320aic31xx: Fix inverted BCLK handling Andrew F. Davis
2017-12-01 13:42   ` Applied "ASoC: tlv320aic31xx: Handle inverted BCLK in non-DSP modes" to the asoc tree Mark Brown
2017-11-29 21:32 ` [PATCH v2 14/19] ASoC: tlv320aic31xx: Remove regulator notification handling Andrew F. Davis
2017-12-01 13:36   ` Mark Brown
2017-12-01 15:01     ` Andrew F. Davis
2017-12-01 15:55       ` Mark Brown
2017-11-29 21:32 ` [PATCH v2 15/19] ASoC: tlv320aic31xx: Reset registers during power up Andrew F. Davis
2017-12-01 13:37   ` Mark Brown
2017-12-01 15:04     ` Andrew F. Davis
2017-12-01 15:55       ` Mark Brown
2017-11-29 21:32 ` [PATCH v2 16/19] ASoC: tlv320aic31xx: Add short circuit detection support Andrew F. Davis
     [not found]   ` <20171129213300.20021-17-afd-l0cyMroinI0@public.gmane.org>
2017-12-01 13:39     ` Mark Brown
2017-12-01 15:32       ` Andrew F. Davis
2017-12-01 15:57         ` Mark Brown
2017-12-06 17:15           ` Andrew F. Davis
2017-12-06 20:22         ` Andrew F. Davis
2017-12-07 12:03           ` Mark Brown
2017-12-07 15:37             ` Andrew F. Davis
2017-12-07 17:23               ` Mark Brown
2017-11-29 21:32 ` [PATCH v2 17/19] ASoC: tlv320aic31xx: Add overflow " Andrew F. Davis
2017-11-29 21:33 ` [PATCH v2 19/19] ASoC: tlv320aic31xx: Add button press detection Andrew F. Davis

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=E1eKO1V-0000Vn-EA@debutante \
    --to=broonie@kernel.org \
    --cc=afd@ti.com \
    --cc=alsa-devel@alsa-project.org \
    --cc=bcousson@baylibre.com \
    --cc=devicetree@vger.kernel.org \
    --cc=lgirdwood@gmail.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mark.rutland@arm.com \
    --cc=robh+dt@kernel.org \
    --cc=tony@atomide.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox